// Generator created by Nikolay Budin

#ifdef DEBUG
#  define _GLIBCXX_DEBUG
#endif
#include <bits/stdc++.h>
#include <ext/pb_ds/assoc_container.hpp>
#include "testlib.h"
#define ff first
#define ss second
#define szof(x) ((int)x.size())
#ifndef LOCAL
#  define cerr __get_ce
#endif

using namespace std;
typedef long long ll;
typedef long double ld;
typedef pair<int, int> pii;
typedef unsigned long long ull;

using namespace __gnu_pbds;
template <typename T> using ordered_set = tree<T, null_type, less<T>, rb_tree_tag, tree_order_statistics_node_update>;
template <typename K, typename V> using ordered_map = tree<K, V, less<K>, rb_tree_tag, tree_order_statistics_node_update>;

int const INF = (int)1e9 + 1e3;
ll const INFL = (ll)1e18 + 1e6;

struct point {
	int x, y;
	point(int _x, int _y) : x(_x), y(_y) {}
	point() {}

	point operator+(point const& other) const {
		return point(x + other.x, y + other.y);
	}

	point operator-(point const& other) const {
		return point(x - other.x, y - other.y);
	}

	bool operator<(point const& other) const {
		return x < other.x || (x == other.x && y < other.y);
	}

	bool operator!=(point const& other) const {
		return x != other.x || y != other.y;
	}

	ll len2() const {
		return (ll) x * x + (ll) y * y;
	}
};

ostream& operator<<(ostream& o, point const& p) {
	o << "(" << p.x << ", " << p.y << ")";
	return o;
}

ll cross(point const& p1, point const& p2) {
	return (ll) p1.x * p2.y - (ll) p1.y * p2.x;
}

vector<point> build_convex_hull(vector<point> points) {
	if (!szof(points)) {
		return points;
	}
	point center = *min_element(points.begin(), points.end());
	vector<point> st;
	for (auto p : points) {
		if (p != center) {
			st.push_back(p - center);
		}
	}

	swap(st, points);
	st.clear();
	st.push_back(point(0, 0));

	sort(points.begin(), points.end(), [&](auto& a, auto& b) {
		ll val = cross(a, b);
		if (val) {
			return val > 0;
		}
		return a.len2() < b.len2();
	});

	for (auto p : points) {
		while (szof(st) >= 2 && cross(st.back() - st[szof(st) - 2], p - st.back()) <= 0) {
			st.pop_back();
		}
		st.push_back(p);
	}

	for (auto& p : st) {
		p = p + center;
	}

	return st;
}

ll calc_area(vector<point> const& poly) {
	ll ret = 0;
	for (int i = 0; i < szof(poly); ++i) {
		int next = (i + 1) % szof(poly);
		ret += cross(poly[i], poly[next]);
	}
	return ret;
}

bool is_inside(vector<point> const& poly, point const& p) {
	for (int i = 0; i < szof(poly); ++i) {
		int next = (i + 1) % szof(poly);
		if (cross(poly[next] - poly[i], p - poly[i]) <= 0) {
			return false;
		}
	}
	return true;
}

const int MAXC = 1'000'000'000;

int main(int argc, char* argv[]) {
	registerGen(argc, argv, 1);

	int n = opt<int>("n");

	vector<point> sides;
	for (int i = -600; i <= 600; ++i) {
		for (int j = -600; j <= 600; ++j) {
			if (__testlib_opts.count("special")) {
				if (i >= 0 || j <= 0) {
					continue;
				}
			}
			if (i == 0 && j == 0) {
				continue;
			}
			if (__gcd(abs(i), abs(j)) == 1) {
				sides.push_back(point(i, j));
			}
		}
	}

	shuffle(sides.begin(), sides.end());
	sides.resize(n - 1);
	point tot(0, 0);
	for (auto v : sides) {
		tot = tot - v;
	}

	if (tot != point(0, 0)) {
		sides.push_back(tot);
	}

	sort(sides.begin(), sides.end(), [&](auto& p1, auto& p2) {
		bool fl1 = p1.y > 0 || (p1.y == 0 && p1.x > 0);
		bool fl2 = p2.y > 0 || (p2.y == 0 && p2.x > 0);
		if (fl1 != fl2) {
			return fl1 < fl2;
		}
		return cross(p1, p2) > 0;
	});

	vector<point> poly = {point(0, 0)};
	for (auto v : sides) {
		poly.push_back(poly.back() + v);
	}
	poly.pop_back();

	int minx = INF, maxx = -INF;
	int miny = INF, maxy = -INF;
	for (auto p : poly) {
		minx = min(minx, p.x);
		maxx = max(maxx, p.x);

		miny = min(miny, p.y);
		maxy = max(maxy, p.y);
	}

	if (__testlib_opts.count("special")) {
		poly.front() = point(minx, miny);
	}

	int shiftx = rnd.next(-MAXC - minx, MAXC - maxx);
	int shifty = rnd.next(-MAXC - miny, MAXC - maxy);
	point shift(shiftx, shifty);

	for (auto& p : poly) {
		p = p + shift;
	}

	rotate(poly.begin(), poly.begin() + rnd.next(szof(poly)), poly.end());
	// cerr << minx << " " << maxx << " " << miny << " " << maxy << endl;

	vector<point> points = poly;
	if (__testlib_opts.count("mess_inside")) {
		int q = opt<int>("mess_inside");
		for (int i = 0; i < q; ++i) {
			point p(0, 0);
			while (true) {
				int x = rnd.next(minx + shiftx, maxx + shiftx);
				int y = rnd.next(miny + shifty, maxy + shifty);
				p = point(x, y);
				if (is_inside(poly, p)) {
					break;
				}
				// cerr << x << " " << y << endl;
			}
			points.push_back(p);
		}
		shuffle(points.begin(), points.end());
	}

	cout << szof(points) << "\n";

	for (auto p : points) {
		cout << p.x << " " << p.y << "\n";
	}

	return 0;
}