// Created by Nikolay Budin

#ifdef DEBUG
#  define _GLIBCXX_DEBUG
#endif
#include <bits/stdc++.h>
#include <ext/pb_ds/assoc_container.hpp>
#include "testlib.h"
#define ff first
#define ss second
#define szof(x) ((int)x.size())
#ifndef LOCAL
#  define cerr __get_ce
#endif

using namespace std;
typedef long long ll;
typedef long double ld;
typedef pair<int, int> pii;
typedef unsigned long long ull;

using namespace __gnu_pbds;
template <typename T> using ordered_set = tree<T, null_type, less<T>, rb_tree_tag, tree_order_statistics_node_update>;
template <typename K, typename V> using ordered_map = tree<K, V, less<K>, rb_tree_tag, tree_order_statistics_node_update>;

int const INF = (int)1e9 + 1e3;
ll const INFL = (ll)1e18 + 1e6;

const double PI = atan2(0, -1);

struct point {
	int x, y;
	point(int _x, int _y) : x(_x), y(_y) {}
	point operator+(point const& other) const {
		return point(x + other.x, y + other.y);
	}
	point operator-(point const& other) const {
		return point(x - other.x, y - other.y);
	}

	bool operator<(point const& other) const {
		return x < other.x || (x == other.x || y < other.y);
	}

	bool operator!=(point const& other) const {
		return x != other.x || y != other.y;
	}

	ll len2() const {
		return (ll) x * x + (ll) y * y;
	}
};

ll cross(point const& p1, point const& p2) {
	return (ll) p1.x * p2.y - (ll) p1.y * p2.x;
}

ll dot(point const& p1, point const& p2) {
	return (ll) p1.x * p2.x + (ll) p1.y * p2.y;
}

double get_ang(point const& p1, point const& p2) {
	return atan2(cross(p1, p2), dot(p1, p2));
}

vector<point> build_convex_hull(vector<point> points) {
	point center = *min_element(points.begin(), points.end());
	vector<point> st;
	for (auto p : points) {
		if (p != center) {
			st.push_back(p - center);
		}
	}

	swap(st, points);
	st.clear();
	st.push_back(point(0, 0));

	sort(points.begin(), points.end(), [&](auto& a, auto& b) {
		ll val = cross(a, b);
		if (val) {
			return val > 0;
		}
		return a.len2() < b.len2();
	});

	int pos = szof(points) - 1;
	while (pos > 0 && !cross(points[pos - 1], points.back())) {
		--pos;
	}
	reverse(points.begin() + pos, points.end());

	for (auto p : points) {
		while (szof(st) >= 2 && cross(st.back() - st[szof(st) - 2], p - st.back()) < 0) {
			st.pop_back();
		}
		st.push_back(p);
	}

	return st;
}

int MAXN = 100'000;
const int MAXC = 1'000'000'000;

int main(int argc, char* argv[]) {
	registerValidation(argc, argv);

	if (validator.group() == "1") {
		MAXN = 1000;
	}

	int n = inf.readInt(2, MAXN, "n");
	inf.readEoln();
	set<pii> points_set;
	vector<point> points;

	for (int i = 0; i < n; ++i) {
		int x = inf.readInt(-MAXC, MAXC, format("x_%d", i + 1));
		inf.readSpace();
		int y = inf.readInt(-MAXC, MAXC, format("y_%d", i + 1));
		inf.readEoln();
		ensure(points_set.insert({x, y}).ss);
		points.push_back(point(x, y));
	}

	inf.readEof();

	if (validator.group() == "2") {
		ensure(3 <= n);
		double ang = 0;
		for (int i = 0; i < n; ++i) {
			int next = (i + 1) % n;
			int nnext = (next + 1) % n;
			// cerr << cross(points[next] - points[i], points[nnext] - points[next]) << endl;
			ensure(cross(points[next] - points[i], points[nnext] - points[next]) > 0);
			ang += get_ang(points[next] - points[i], points[nnext] - points[next]);
		}

		ensure(abs(ang - PI * 2) < 1e-3);
	}

	if (validator.group() == "3") {
		auto hull = build_convex_hull(points);
		ensure(n - szof(hull) <= 10);
	}

	return 0;
}