// Created by Nikolay Budin

#ifdef DEBUG
#  define _GLIBCXX_DEBUG
#endif
#include <bits/stdc++.h>
#include <ext/pb_ds/assoc_container.hpp>
#define ff first
#define ss second
#define szof(x) ((int)x.size())
#ifndef LOCAL
#  define cerr __get_ce
#endif

using namespace std;
typedef long long ll;
typedef long double ld;
typedef pair<int, int> pii;
typedef unsigned long long ull;

using namespace __gnu_pbds;
template <typename T> using ordered_set = tree<T, null_type, less<T>, rb_tree_tag, tree_order_statistics_node_update>;
template <typename K, typename V> using ordered_map = tree<K, V, less<K>, rb_tree_tag, tree_order_statistics_node_update>;

int const INF = (int)1e9 + 1e3;
ll const INFL = (ll)1e18 + 1e6;
#ifdef LOCAL
	mt19937 tw(9450189);
#else
	mt19937 tw(chrono::high_resolution_clock::now().time_since_epoch().count());
#endif
uniform_int_distribution<ll> ll_distr;
ll rnd(ll a, ll b) { return ll_distr(tw) % (b - a + 1) + a; }

struct point {
	int x, y;
	point(int _x, int _y) : x(_x), y(_y) {}

	point operator+(point const& other) const {
		return point(x + other.x, y + other.y);
	}

	point operator-(point const& other) const {
		return point(x - other.x, y - other.y);
	}

	bool operator<(point const& other) const {
		return x < other.x || (x == other.x && y < other.y);
	}

	bool operator!=(point const& other) const {
		return x != other.x || y != other.y;
	}

	ll len2() const {
		return (ll) x * x + (ll) y * y;
	}
};

ostream& operator<<(ostream& o, point const& p) {
	o << "(" << p.x << ", " << p.y << ")";
	return o;
}

ll cross(point const& p1, point const& p2) {
	return (ll) p1.x * p2.y - (ll) p1.y * p2.x;
}

vector<point> build_convex_hull(vector<point> points) {
	if (!szof(points)) {
		return points;
	}
	point center = *min_element(points.begin(), points.end());
	vector<point> st;
	for (auto p : points) {
		if (p != center) {
			st.push_back(p - center);
		}
	}

	swap(st, points);
	st.clear();
	st.push_back(point(0, 0));

	sort(points.begin(), points.end(), [&](auto& a, auto& b) {
		ll val = cross(a, b);
		if (val) {
			return val > 0;
		}
		return a.len2() < b.len2();
	});

	for (auto p : points) {
		while (szof(st) >= 2 && cross(st.back() - st[szof(st) - 2], p - st.back()) <= 0) {
			st.pop_back();
		}
		st.push_back(p);
	}

	for (auto& p : st) {
		p = p + center;
	}

	return st;
}

ll calc_area(vector<point> const& poly) {
	ll ret = 0;
	for (int i = 0; i < szof(poly); ++i) {
		int next = (i + 1) % szof(poly);
		ret += cross(poly[i], poly[next]);
	}
	return ret;
}

void solve() {
	int n;
	cin >> n;
	vector<point> points;
	for (int i = 0; i < n; ++i) {
		int x, y;
		cin >> x >> y;
		points.push_back(point(x, y));
	}

	auto hull = build_convex_hull(points);

	ll tot_area = calc_area(hull);

	if (tot_area == 0) {
		cout << "0\n";
		return;
	}

	set<point> in_hull(hull.begin(), hull.end());

	vector<point> left;
	for (auto p : points) {
		if (!in_hull.count(p)) {
			left.push_back(p);
		}
	}

	auto inner_hull = build_convex_hull(left);

	vector<ll> pref = {0};
	for (int i = 0; i < szof(inner_hull); ++i) {
		int next = (i + 1) % szof(inner_hull);
		pref.push_back(pref.back() + cross(inner_hull[i], inner_hull[next]));
	}

	auto get_sum = [&](int l, int r) {
		if (l == r) {
			return 0ll;
		}

		if (l < r) {
			return pref[r] - pref[l];
		}

		return pref.back() - pref[l] + pref[r];
	};

	int p1 = 0, p2 = 0;

	ll ans = INFL * 9;

	for (int i = 0; i < szof(hull); ++i) {
		int prev = (i - 1 + szof(hull)) % szof(hull);
		int next = (i + 1) % szof(hull);

		ll cur_area = tot_area - cross(hull[prev], hull[i]) - cross(hull[i], hull[next]);
		
		if (szof(inner_hull) == 0) {
			cur_area += cross(hull[prev], hull[next]);
		} else {
			while (true) {
				int next_p1 = (p1 + 1) % szof(inner_hull);
				if (cross(inner_hull[p1] - hull[prev], inner_hull[next_p1] - hull[prev]) < 0) {
					p1 = next_p1;
				} else {
					break;
				}
			}
			while (true) {
				int prev_p1 = (p1 - 1 + szof(inner_hull)) % szof(inner_hull);
				if (cross(inner_hull[p1] - hull[prev], inner_hull[prev_p1] - hull[prev]) < 0) {
					p1 = prev_p1;
				} else {
					break;
				}
			}

			while (true) {
				int next_p2 = (p2 + 1) % szof(inner_hull);
				if (cross(inner_hull[p2] - hull[next], inner_hull[next_p2] - hull[next]) > 0) {
					p2 = next_p2;
				} else {
					break;
				}
			}
			while (true) {
				int prev_p2 = (p2 - 1 + szof(inner_hull)) % szof(inner_hull);
				if (cross(inner_hull[p2] - hull[next], inner_hull[prev_p2] - hull[next]) > 0) {
					p2 = prev_p2;
				} else {
					break;
				}
			}

			if (cross(hull[next] - hull[prev], inner_hull[p1] - hull[prev]) < 0) {
				cur_area += get_sum(p1, p2) + cross(hull[prev], inner_hull[p1]) + cross(inner_hull[p2], hull[next]);
			} else {
				cur_area += cross(hull[prev], hull[next]);
			}
		}

		ans = min(ans, cur_area);
	}

	cout << ans << "\n";
}


int main() {
#ifdef LOCAL
	auto start_time = clock();
	cerr << setprecision(3) << fixed;
#endif
	cout << setprecision(15) << fixed;
	ios::sync_with_stdio(false);
	cin.tie(nullptr);

	int test_count = 1;
	// cin >> test_count;
	for (int test = 1; test <= test_count; ++test) {
		solve();
	}

#ifdef LOCAL
	auto end_time = clock();
	cerr << "Execution time: " << (end_time - start_time) * (int)1e3 / CLOCKS_PER_SEC << " ms\n";
#endif
}